==> webcamoid-debug-9.1.0-1-x86_64.pkg.tar.zst: usr/src/debug/webcamoid/webcamoid-9.1.0/libAvKys/Plugins/AdjustHSL/AdjustHSL_autogen/EWIEGA46WW/qrc_AdjustHSL.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.9
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/webcamoid/src/webcamoid-9.1.0/libAvKys/Plugins/AdjustHSL/share/qml/main.qml
  0x0,0x0,0x3,0xb3,
  0x0,
  0x0,0xc,0xaf,0x78,0x9c,0xbd,0x55,0x4d,0x73,0xe2,0x46,0x10,0xbd,0xeb,0x57,0x74,
  0xed,0x9,0x6f,0xb1,0x22,0xc6,0xe5,0xc3,0xb2,0x9b,0x54,0xb1,0x94,0x6d,0xa8,0x22,
  0xd8,0x8b,0x70,0x5c,0x3e,0x8e,0xa4,0x16,0x9a,0x44,0xcc,0x68,0xe7,0x3,0xcc,0xa6,
  0xfc,0xdf,0xd3,0x23,0x40,0x92,0x41,0x76,0xb0,0x5d,0x89,0x4e,0x9e,0xfe,0x78,0xf3,
  0x5e,0xf7,0x63,0xdc,0xf9,0x8,0x77,0x18,0x46,0x6c,0x21,0x79,0xdc,0x86,0x55,0xf1,
  0x27,0x44,0x2c,0x37,0x56,0x21,0xb0,0x3c,0xcf,0x78,0xc4,0xc,0x97,0xc2,0xf7,0xe0,
  0x23,0xc,0x64,0xbe,0x56,0x7c,0x9e,0x1a,0x68,0xd,0x4e,0xa0,0xfb,0x4b,0xb7,0xb,
  0x70,0x25,0xc5,0x4f,0x96,0x49,0xb8,0x78,0xc0,0x1f,0x96,0x63,0x6,0x37,0x18,0x4b,
  0x81,0x54,0xee,0x3a,0x4a,0x6c,0xe0,0x1a,0x12,0x85,0x8,0x5a,0x26,0x66,0xc5,0x14,
  0xf6,0x60,0x2d,0x2d,0xdd,0x24,0x40,0x61,0xcc,0xb5,0x51,0x3c,0xb4,0x6,0x81,0x1b,
  0x60,0x22,0xee,0x48,0x5,0xb,0x19,0xf3,0x64,0xed,0x40,0x28,0x66,0x45,0x8c,0xa,
  0x4c,0x8a,0x60,0x50,0x2d,0x34,0xc8,0xa4,0x38,0x5c,0x4d,0x6e,0xe1,0xa,0x5,0x2a,
  0x46,0xf7,0xda,0x90,0xc8,0xc2,0x98,0x47,0x28,0x34,0x71,0xd7,0x90,0xbb,0x88,0x4e,
  0x31,0x86,0xb0,0xc0,0x71,0x1d,0x97,0x8e,0x43,0xb0,0xe5,0x0,0x97,0x92,0x80,0xb,
  0x7d,0x6d,0x40,0x4e,0x79,0x5,0x4b,0x54,0x9a,0xce,0x70,0xb6,0xbb,0x63,0xb,0xd8,
  0x6,0xa9,0x1c,0x48,0x8b,0x19,0xc7,0x5c,0x81,0xcc,0x5d,0xdf,0x9,0xd1,0x5d,0x43,
  0xc6,0x4c,0xd5,0xea,0x37,0x69,0xaf,0x24,0xd2,0x51,0x14,0xc0,0xa9,0xcc,0x49,0x4e,
  0x4a,0x78,0x24,0x70,0xc5,0xb3,0xc,0x42,0x4,0xab,0x31,0xb1,0x59,0xdb,0xf5,0x53,
  0x31,0xdc,0x8d,0x66,0xc3,0xeb,0xdb,0x19,0xf4,0x27,0xf7,0x70,0xd7,0x9f,0x4e,0xfb,
  0x93,0xd9,0xfd,0x17,0x2a,0x36,0xa9,0xa4,0x2c,0x2e,0x71,0x3,0xc5,0x17,0xb4,0x28,
  0x42,0x26,0x51,0x8a,0x9,0xb3,0x26,0xee,0xe,0xe1,0xf7,0x8b,0xe9,0x60,0x48,0x2d,
  0xfd,0x6f,0xa3,0xf1,0x68,0x76,0x4f,0xa,0xe0,0x72,0x34,0x9b,0x5c,0x4,0x1,0x5c,
  0x5e,0x4f,0xa1,0xf,0x37,0xfd,0xe9,0x6c,0x34,0xb8,0x1d,0xf7,0xa7,0x70,0x73,0x3b,
  0xbd,0xb9,0xe,0x2e,0x7c,0x80,0x0,0x1d,0x2d,0xb7,0xc1,0x97,0xe6,0x9b,0x14,0x2b,
  0xa2,0x19,0xc6,0x68,0x18,0xcf,0xf4,0x4e,0xf5,0x3d,0x6d,0x55,0x13,0xbb,0x2c,0x86,
  0x94,0x2d,0x91,0xb6,0x1b,0x21,0x5f,0x12,0x37,0x6,0x11,0xd9,0xe7,0xdf,0x37,0xe7,
  0x40,0xc8,0x50,0x62,0x5e,0xc8,0xac,0xa6,0xe8,0xc3,0x28,0x1,0x21,0x4d,0x1b,0x34,
  0x11,0xfc,0x9a,0x1a,0x93,0xf7,0x3a,0x9d,0xd5,0x6a,0xe5,0xcf,0x85,0xf5,0xa5,0x9a,
  0x77,0xb2,0xd,0x80,0xee,0xfc,0x56,0x5b,0xc1,0xa7,0x80,0x1b,0x32,0xdb,0xae,0xbc,
  0x44,0x9b,0x13,0xb8,0xd,0x7d,0x2e,0x3b,0x54,0xd8,0xf1,0x3c,0x1a,0xa1,0x54,0x6,
  0xbe,0x9b,0xef,0x96,0x47,0x7f,0x41,0xd7,0x3f,0xed,0xee,0xc5,0xfc,0x81,0x14,0x46,
  0xc9,0x4c,0x53,0xf2,0x7c,0x3f,0x37,0x66,0x64,0xa,0xa3,0xe1,0xd4,0x3f,0xf3,0xbc,
  0x2b,0xc5,0xe3,0x4d,0x0,0xfe,0xf6,0x80,0x3e,0x1e,0xf7,0x48,0xbd,0x48,0xf8,0x5c,
  0x17,0xe7,0x48,0x66,0x76,0x21,0x74,0xf,0xa8,0xd8,0x9d,0x9,0x59,0x60,0xe4,0xfc,
  0xa4,0xb7,0x1d,0xee,0x33,0x4c,0xcd,0xd1,0xf4,0xa0,0x1f,0xff,0x69,0xb5,0x19,0x6,
  0x63,0xaf,0x4c,0x25,0x56,0x14,0xe5,0x20,0xc5,0xd0,0xe2,0x20,0x65,0x62,0x8e,0x71,
  0x2b,0xb5,0x78,0x52,0x96,0x54,0x38,0xee,0xd3,0x59,0x4c,0x85,0xfe,0x92,0x65,0x16,
  0xe1,0x57,0xa0,0xca,0xa7,0xe9,0x3c,0x7c,0x2e,0xfd,0xd8,0x78,0x6b,0xc0,0xe8,0x85,
  0x28,0x7e,0x39,0xbb,0xcb,0x75,0x19,0x79,0x81,0x43,0xd5,0x56,0xde,0x55,0xf5,0xed,
  0x33,0x3a,0xae,0xb8,0x99,0xdf,0xd8,0x2e,0xb8,0x60,0x22,0x2a,0x67,0x93,0xed,0x2,
  0x2f,0xb0,0x2b,0x9b,0xca,0xfb,0xca,0xae,0x7d,0x6e,0xc7,0x94,0x3e,0x7a,0x35,0x7e,
  0x63,0x16,0xd2,0xe3,0x58,0x5d,0xe9,0x2c,0x61,0x1e,0xcc,0xb0,0x36,0x69,0x83,0xf,
  0xb4,0xed,0x1f,0x7a,0xa6,0x5a,0x1f,0x28,0xfe,0xe1,0xc4,0xab,0x50,0x82,0x8c,0xbb,
  0x17,0xf0,0x69,0xff,0x66,0xa9,0x65,0xa8,0x60,0x52,0xb3,0x8b,0x5f,0x5f,0xa3,0x36,
  0x98,0x7,0xfc,0x27,0xe5,0x4f,0xab,0x79,0x29,0xb9,0xe8,0xc1,0xa7,0xb3,0xf3,0xcf,
  0x15,0x7,0x49,0xa6,0xac,0x9d,0x37,0x36,0xf6,0x13,0x7a,0x9e,0xee,0x78,0x6c,0x52,
  0x22,0xad,0x6a,0xa8,0xfd,0x28,0x42,0xad,0x79,0x98,0xa1,0x2f,0xd8,0x2,0x77,0x92,
  0x7c,0x27,0xa5,0xda,0x8b,0x14,0x7f,0x38,0x6a,0xdb,0x55,0xec,0x31,0xa4,0xd1,0x15,
  0xc4,0xeb,0x62,0x73,0x2e,0xbe,0xc9,0x87,0x7d,0xb5,0x85,0x47,0x8f,0x53,0xbb,0x51,
  0xb6,0x35,0xbd,0x3b,0x3c,0x11,0xb8,0x8d,0x1b,0xd9,0x30,0x9d,0x6d,0x6e,0x17,0x28,
  0x2b,0xe8,0x9f,0x94,0x61,0xa4,0xf3,0x3f,0x19,0xc0,0xc4,0x2e,0x42,0x54,0xad,0x42,
  0x52,0x7d,0xeb,0xcf,0x98,0x26,0x38,0xfc,0x15,0xd4,0xbd,0x53,0xa5,0x8f,0xb2,0x50,
  0x3,0xda,0xc1,0x6c,0x1b,0x7e,0x77,0x2f,0x18,0xaa,0x7b,0x7e,0xfe,0x64,0xde,0xf5,
  0xf3,0x1b,0xc,0x55,0x7b,0x7,0x8e,0x1d,0x6b,0xc5,0xf7,0x35,0xf6,0x7a,0xe3,0x24,
  0x4a,0xb3,0xd5,0x88,0x36,0x79,0xae,0xae,0xe3,0x19,0xeb,0xd5,0x4a,0xde,0xe3,0xc0,
  0xf7,0x4e,0xec,0x95,0x7e,0x1c,0x1f,0x3c,0x7d,0x75,0x3b,0x96,0xd9,0xa3,0xdc,0x78,
  0x88,0x75,0xb0,0x82,0xc3,0x97,0xf6,0xff,0xf3,0x62,0xf5,0xee,0x1f,0x3b,0xd8,0x92,
  0xed,0x6b,0x9c,0xf8,0xa6,0x29,0x94,0x3e,0xac,0x48,0x36,0xd9,0xb0,0x26,0xe1,0x19,
  0x17,0x56,0x15,0xef,0x31,0xe1,0xfb,0x46,0xd5,0x64,0xc1,0x47,0xef,0x1f,0x65,0x5f,
  0xcc,0x52,
  
};

static const unsigned char qt_resource_name[] = {
  // AdjustHSL
  0x0,0x9,
  0x1,0xca,0x2,0x1c,
  0x0,0x41,
  0x0,0x64,0x0,0x6a,0x0,0x75,0x0,0x73,0x0,0x74,0x0,0x48,0x0,0x53,0x0,0x4c,
    // share
  0x0,0x5,
  0x0,0x79,0xe8,0x85,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x72,0x0,0x65,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // main.qml
  0x0,0x8,
  0x8,0x1,0x5a,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/AdjustHSL
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/AdjustHSL/share
  0x0,0x0,0x0,0x18,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/AdjustHSL/share/qml
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,
  // :/AdjustHSL/share/qml/main.qml
  0x0,0x0,0x0,0x34,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x88,0xac,0x68,0xcf,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_AdjustHSL)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_AdjustHSL)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_AdjustHSL)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_AdjustHSL)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_AdjustHSL)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_AdjustHSL)(); }
   } dummy;
}

==> webcamoid-debug-9.1.1-2-x86_64.pkg.tar.zst: usr/src/debug/webcamoid/webcamoid-9.1.1/libAvKys/Plugins/AdjustHSL/AdjustHSL_autogen/EWIEGA46WW/qrc_AdjustHSL.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.10
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/webcamoid/src/webcamoid-9.1.1/libAvKys/Plugins/AdjustHSL/share/qml/main.qml
  0x0,0x0,0x3,0xb3,
  0x0,
  0x0,0xc,0xaf,0x78,0x9c,0xbd,0x55,0x4d,0x73,0xe2,0x46,0x10,0xbd,0xeb,0x57,0x74,
  0xed,0x9,0x6f,0xb1,0x22,0xc6,0xe5,0xc3,0xb2,0x9b,0x54,0xb1,0x94,0x6d,0xa8,0x22,
  0xd8,0x8b,0x70,0x5c,0x3e,0x8e,0xa4,0x16,0x9a,0x44,0xcc,0x68,0xe7,0x3,0xcc,0xa6,
  0xfc,0xdf,0xd3,0x23,0x40,0x92,0x41,0x76,0xb0,0x5d,0x89,0x4e,0x9e,0xfe,0x78,0xf3,
  0x5e,0xf7,0x63,0xdc,0xf9,0x8,0x77,0x18,0x46,0x6c,0x21,0x79,0xdc,0x86,0x55,0xf1,
  0x27,0x44,0x2c,0x37,0x56,0x21,0xb0,0x3c,0xcf,0x78,0xc4,0xc,0x97,0xc2,0xf7,0xe0,
  0x23,0xc,0x64,0xbe,0x56,0x7c,0x9e,0x1a,0x68,0xd,0x4e,0xa0,0xfb,0x4b,0xb7,0xb,
  0x70,0x25,0xc5,0x4f,0x96,0x49,0xb8,0x78,0xc0,0x1f,0x96,0x63,0x6,0x37,0x18,0x4b,
  0x81,0x54,0xee,0x3a,0x4a,0x6c,0xe0,0x1a,0x12,0x85,0x8,0x5a,0x26,0x66,0xc5,0x14,
  0xf6,0x60,0x2d,0x2d,0xdd,0x24,0x40,0x61,0xcc,0xb5,0x51,0x3c,0xb4,0x6,0x81,0x1b,
  0x60,0x22,0xee,0x48,0x5,0xb,0x19,0xf3,0x64,0xed,0x40,0x28,0x66,0x45,0x8c,0xa,
  0x4c,0x8a,0x60,0x50,0x2d,0x34,0xc8,0xa4,0x38,0x5c,0x4d,0x6e,0xe1,0xa,0x5,0x2a,
  0x46,0xf7,0xda,0x90,0xc8,0xc2,0x98,0x47,0x28,0x34,0x71,0xd7,0x90,0xbb,0x88,0x4e,
  0x31,0x86,0xb0,0xc0,0x71,0x1d,0x97,0x8e,0x43,0xb0,0xe5,0x0,0x97,0x92,0x80,0xb,
  0x7d,0x6d,0x40,0x4e,0x79,0x5,0x4b,0x54,0x9a,0xce,0x70,0xb6,0xbb,0x63,0xb,0xd8,
  0x6,0xa9,0x1c,0x48,0x8b,0x19,0xc7,0x5c,0x81,0xcc,0x5d,0xdf,0x9,0xd1,0x5d,0x43,
  0xc6,0x4c,0xd5,0xea,0x37,0x69,0xaf,0x24,0xd2,0x51,0x14,0xc0,0xa9,0xcc,0x49,0x4e,
  0x4a,0x78,0x24,0x70,0xc5,0xb3,0xc,0x42,0x4,0xab,0x31,0xb1,0x59,0xdb,0xf5,0x53,
  0x31,0xdc,0x8d,0x66,0xc3,0xeb,0xdb,0x19,0xf4,0x27,0xf7,0x70,0xd7,0x9f,0x4e,0xfb,
  0x93,0xd9,0xfd,0x17,0x2a,0x36,0xa9,0xa4,0x2c,0x2e,0x71,0x3,0xc5,0x17,0xb4,0x28,
  0x42,0x26,0x51,0x8a,0x9,0xb3,0x26,0xee,0xe,0xe1,0xf7,0x8b,0xe9,0x60,0x48,0x2d,
  0xfd,0x6f,0xa3,0xf1,0x68,0x76,0x4f,0xa,0xe0,0x72,0x34,0x9b,0x5c,0x4,0x1,0x5c,
  0x5e,0x4f,0xa1,0xf,0x37,0xfd,0xe9,0x6c,0x34,0xb8,0x1d,0xf7,0xa7,0x70,0x73,0x3b,
  0xbd,0xb9,0xe,0x2e,0x7c,0x80,0x0,0x1d,0x2d,0xb7,0xc1,0x97,0xe6,0x9b,0x14,0x2b,
  0xa2,0x19,0xc6,0x68,0x18,0xcf,0xf4,0x4e,0xf5,0x3d,0x6d,0x55,0x13,0xbb,0x2c,0x86,
  0x94,0x2d,0x91,0xb6,0x1b,0x21,0x5f,0x12,0x37,0x6,0x11,0xd9,0xe7,0xdf,0x37,0xe7,
  0x40,0xc8,0x50,0x62,0x5e,0xc8,0xac,0xa6,0xe8,0xc3,0x28,0x1,0x21,0x4d,0x1b,0x34,
  0x11,0xfc,0x9a,0x1a,0x93,0xf7,0x3a,0x9d,0xd5,0x6a,0xe5,0xcf,0x85,0xf5,0xa5,0x9a,
  0x77,0xb2,0xd,0x80,0xee,0xfc,0x56,0x5b,0xc1,0xa7,0x80,0x1b,0x32,0xdb,0xae,0xbc,
  0x44,0x9b,0x13,0xb8,0xd,0x7d,0x2e,0x3b,0x54,0xd8,0xf1,0x3c,0x1a,0xa1,0x54,0x6,
  0xbe,0x9b,0xef,0x96,0x47,0x7f,0x41,0xd7,0x3f,0xed,0xee,0xc5,0xfc,0x81,0x14,0x46,
  0xc9,0x4c,0x53,0xf2,0x7c,0x3f,0x37,0x66,0x64,0xa,0xa3,0xe1,0xd4,0x3f,0xf3,0xbc,
  0x2b,0xc5,0xe3,0x4d,0x0,0xfe,0xf6,0x80,0x3e,0x1e,0xf7,0x48,0xbd,0x48,0xf8,0x5c,
  0x17,0xe7,0x48,0x66,0x76,0x21,0x74,0xf,0xa8,0xd8,0x9d,0x9,0x59,0x60,0xe4,0xfc,
  0xa4,0xb7,0x1d,0xee,0x33,0x4c,0xcd,0xd1,0xf4,0xa0,0x1f,0xff,0x69,0xb5,0x19,0x6,
  0x63,0xaf,0x4c,0x25,0x56,0x14,0xe5,0x20,0xc5,0xd0,0xe2,0x20,0x65,0x62,0x8e,0x71,
  0x2b,0xb5,0x78,0x52,0x96,0x54,0x38,0xee,0xd3,0x59,0x4c,0x85,0xfe,0x92,0x65,0x16,
  0xe1,0x57,0xa0,0xca,0xa7,0xe9,0x3c,0x7c,0x2e,0xfd,0xd8,0x78,0x6b,0xc0,0xe8,0x85,
  0x28,0x7e,0x39,0xbb,0xcb,0x75,0x19,0x79,0x81,0x43,0xd5,0x56,0xde,0x55,0xf5,0xed,
  0x33,0x3a,0xae,0xb8,0x99,0xdf,0xd8,0x2e,0xb8,0x60,0x22,0x2a,0x67,0x93,0xed,0x2,
  0x2f,0xb0,0x2b,0x9b,0xca,0xfb,0xca,0xae,0x7d,0x6e,0xc7,0x94,0x3e,0x7a,0x35,0x7e,
  0x63,0x16,0xd2,0xe3,0x58,0x5d,0xe9,0x2c,0x61,0x1e,0xcc,0xb0,0x36,0x69,0x83,0xf,
  0xb4,0xed,0x1f,0x7a,0xa6,0x5a,0x1f,0x28,0xfe,0xe1,0xc4,0xab,0x50,0x82,0x8c,0xbb,
  0x17,0xf0,0x69,0xff,0x66,0xa9,0x65,0xa8,0x60,0x52,0xb3,0x8b,0x5f,0x5f,0xa3,0x36,
  0x98,0x7,0xfc,0x27,0xe5,0x4f,0xab,0x79,0x29,0xb9,0xe8,0xc1,0xa7,0xb3,0xf3,0xcf,
  0x15,0x7,0x49,0xa6,0xac,0x9d,0x37,0x36,0xf6,0x13,0x7a,0x9e,0xee,0x78,0x6c,0x52,
  0x22,0xad,0x6a,0xa8,0xfd,0x28,0x42,0xad,0x79,0x98,0xa1,0x2f,0xd8,0x2,0x77,0x92,
  0x7c,0x27,0xa5,0xda,0x8b,0x14,0x7f,0x38,0x6a,0xdb,0x55,0xec,0x31,0xa4,0xd1,0x15,
  0xc4,0xeb,0x62,0x73,0x2e,0xbe,0xc9,0x87,0x7d,0xb5,0x85,0x47,0x8f,0x53,0xbb,0x51,
  0xb6,0x35,0xbd,0x3b,0x3c,0x11,0xb8,0x8d,0x1b,0xd9,0x30,0x9d,0x6d,0x6e,0x17,0x28,
  0x2b,0xe8,0x9f,0x94,0x61,0xa4,0xf3,0x3f,0x19,0xc0,0xc4,0x2e,0x42,0x54,0xad,0x42,
  0x52,0x7d,0xeb,0xcf,0x98,0x26,0x38,0xfc,0x15,0xd4,0xbd,0x53,0xa5,0x8f,0xb2,0x50,
  0x3,0xda,0xc1,0x6c,0x1b,0x7e,0x77,0x2f,0x18,0xaa,0x7b,0x7e,0xfe,0x64,0xde,0xf5,
  0xf3,0x1b,0xc,0x55,0x7b,0x7,0x8e,0x1d,0x6b,0xc5,0xf7,0x35,0xf6,0x7a,0xe3,0x24,
  0x4a,0xb3,0xd5,0x88,0x36,0x79,0xae,0xae,0xe3,0x19,0xeb,0xd5,0x4a,0xde,0xe3,0xc0,
  0xf7,0x4e,0xec,0x95,0x7e,0x1c,0x1f,0x3c,0x7d,0x75,0x3b,0x96,0xd9,0xa3,0xdc,0x78,
  0x88,0x75,0xb0,0x82,0xc3,0x97,0xf6,0xff,0xf3,0x62,0xf5,0xee,0x1f,0x3b,0xd8,0x92,
  0xed,0x6b,0x9c,0xf8,0xa6,0x29,0x94,0x3e,0xac,0x48,0x36,0xd9,0xb0,0x26,0xe1,0x19,
  0x17,0x56,0x15,0xef,0x31,0xe1,0xfb,0x46,0xd5,0x64,0xc1,0x47,0xef,0x1f,0x65,0x5f,
  0xcc,0x52,
  
};

static const unsigned char qt_resource_name[] = {
  // AdjustHSL
  0x0,0x9,
  0x1,0xca,0x2,0x1c,
  0x0,0x41,
  0x0,0x64,0x0,0x6a,0x0,0x75,0x0,0x73,0x0,0x74,0x0,0x48,0x0,0x53,0x0,0x4c,
    // share
  0x0,0x5,
  0x0,0x79,0xe8,0x85,
  0x0,0x73,
  0x0,0x68,0x0,0x61,0x0,0x72,0x0,0x65,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // main.qml
  0x0,0x8,
  0x8,0x1,0x5a,0x5c,
  0x0,0x6d,
  0x0,0x61,0x0,0x69,0x0,0x6e,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/AdjustHSL
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/AdjustHSL/share
  0x0,0x0,0x0,0x18,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/AdjustHSL/share/qml
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,
  // :/AdjustHSL/share/qml/main.qml
  0x0,0x0,0x0,0x34,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x89,0x86,0x25,0x13,0x20,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZlib()
{
    extern const unsigned char qt_resourceFeatureZlib;
    return qt_resourceFeatureZlib;
}
#else
unsigned char qResourceFeatureZlib();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_AdjustHSL)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_AdjustHSL)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_AdjustHSL)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_AdjustHSL)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZlib());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_AdjustHSL)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_AdjustHSL)(); }
   } dummy;
}
